@@ -17,17 +17,16 @@ def process_logs(transaction):
     program_id = '6EF8rrecthR5Dkzon8Nwu78hRvfCKubJ14M5uBEwF6P'
     response = call_solcatcher_ts('process-logs', signature=signature, slot=slot, program_id=program_id, logs=logs)
     return signature
-def get_pair(pair_d=None,mint=None):
+def get_pair(pair_id=None,mint=None,signature=None):
     try:
-        raw_pair_data = call_solcatcher_db('/api/get_pair',pair_id=pair_id)
+        raw_pair_data = call_solcatcher_db('/api/get_pair',mint=mint,pair_id=pair_id,signature=signature)
         pair_data = clean_pair_values(raw_pair_data)
         return pair_data
     except Exception as e:
         input(e)
-def get_transactions_by_pair_id(pair_id):
+def get_transactions(pair_id=None,txn_id=None,signature=None,log_id=None):
     try:
-        raw_transactions = call_solcatcher_db('/api/get_transactions',pair_id=pair_id)
-        
+        raw_transactions = call_solcatcher_db('/api/get_transactions',pair_id=pair_id,txn_id=txn_id,signature=signature,log_id=log_id)
         return raw_transactions
     except Exception as e:
         input(e)
@@ -81,11 +80,11 @@ def get_parsed_logs(transaction):
     parsed_logs = get_if_single(raw_parsed_logs)
     return parsed_logs
 def upsert_pair(pair_data):
-    pair_id = upsertPairData(pair)
+    pair_id = upsertPairData(pair_data)
     return pair_id
 def clean_pair_values(pair):
     pair = get_if_single(pair)
-    if pair:
+    if pair and isinstance(pair,dict):
         for key,value in pair.items():
             if isinstance(value,str):
                 pair[key]= eatAll(value,['"',"'"])
