@@ -1,6 +1,8 @@
 import json
 from abstract_utilities import eatAll
 from abstract_security import get_env_value
+from abstract_apis import get_headers,get_response
+import requests
 def getSolcatcherUrl(endpoint=None):
   return getEndpointUrl(endpoint=endpoint,url='https://solcatcher.io')
 def getSolcatcherPairCatchUrl(endpoint=None):
@@ -16,6 +18,7 @@ def get_db_header(headers=None, api_key=None):
     # Retrieve the key from environment or config
     key = api_key or get_env_value('SOLCATCHER_DB_API_KEY')
        # If key is not None, add the header; otherwise skip it
+    
     if key:
         header["X-API-KEY"] = str(key) if key else ""
     # else do not set "X-API-KEY" at all
@@ -23,7 +26,7 @@ def get_db_header(headers=None, api_key=None):
     return header
 def post_request(endpoint, **kwargs):
     url = getSolcatcherDbCalls(endpoint=endpoint)
-    response = requests.post(url=url, data=json.dumps(kwargs), headers=get_headers())
+    response = requests.post(url=url, data=json.dumps(kwargs), headers=get_db_header())
     return get_response(response)
 def getEndpointUrl(endpoint=None,url=None):
   if endpoint:
